-- ==========================
-- Magic Maze - www.atien.net
-- ==========================

if pge ~= undefined then	shell = "pge"
else				shell = "win"
end

function shell_timer(t) -- t en millisecondes
	if shell == "pge" then
		t = t * 1000
		pge.delay(t)
	elseif shell == "win" then
		local timer = Timer.new()
		timer:start()
		while timer:time() < t do end
		timer:stop()
	end
end

function shell_activate(stuff)
	if shell == "pge" then stuff:activate() end
end

function shell_draw(texture, x, y, width, height, texstartx, texstarty, texendx, texendy, rotation, alpha)
	if rotation == nil then	rotation = 0	end
	if alpha == nil then	alpha = 255	end
	if shell == "pge" then
		if texstartx == nil then pge.texture.draweasy(texture, x, y)
		else
			rotation = rotation * math.pi / 2
			pge.texture.draw(texture, x, y, width, height, texstartx, texstarty, texendx, texendy, rotation, alpha)
		end
	elseif shell == "win" then
		if texstartx == nil then image = screen:blit(x, y, texture)
		else screen:blit(x, y, texture, texstartx, texstarty + rotation * 30, width, height)
		end
	end
end

function shell_loadGFX(gfx)
	if shell == "pge" then		return pge.texture.load(gfx, PGE_RAM)
	elseif shell == "win" then	return Image.load(gfx)
	end
end

function shell_color(r, g, b)
	if shell == "pge" then		return pge.gfx.createcolor(r, g, b)
	elseif shell == "win" then	return Color.new(r, g, b)
	end
end

function shell_drawline(x1, y1, x2, y2, color)
	if shell == "pge" then		pge.gfx.drawline(x1, y1, x2, y2, color)
	elseif shell == "win" then	screen:drawLine(x1, y1, x2, y2, color)
	end
end

function shell_drawcircle(x, y, radius, steps, color)
	if shell == "pge" then		pge.gfx.drawcircleoutline(x, y, radius, steps, color)
	elseif shell == "win" then
		local pi = math.pi
		local step = 2 / (radius * radius * 0.5)
		for i = 0, math.rad(116), step do 
			local a = x - radius * math.cos(pi * i)
			local b = y + radius * math.sin(pi * i)
			if a > 2 and b > 2 and b < 270 then 
				screen:pixel(a, b, color)
			end
		end
	end
end

function shell_startdrawing()
	if shell == "pge" then
		pge.gfx.startdrawing()
		pge.gfx.clearscreen()
	elseif shell == "win" then	screen:clear()
	end
end

function shell_enddrawing()
	if shell == "pge" then
		pge.gfx.enddrawing()
		pge.gfx.swapbuffers()
	elseif shell == "win" then
		screen.waitVblankStart()
		screen.flip()
	end
end

function shell_controlsupdate()
	if shell == "pge" then		return pge.controls.update()
	elseif shell == "win" then	return Controls.read()
	end
end

function shell_controlspress(key)
	if key == "start" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_START)
		elseif shell == "win" then	return pad:start()
		end
	elseif key == "up" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_UP)
		elseif shell == "win" then	return pad:up()
		end
	elseif key == "down" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_DOWN)
		elseif shell == "win" then	return pad:down()
 		end
	elseif key == "left" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_LEFT)
		elseif shell == "win" then	return pad:left()
		end
	elseif key == "right" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_RIGHT)
		elseif shell == "win" then	return pad:right()
		end
	elseif key == "circle" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_CIRCLE)
		elseif shell == "win" then	return pad:circle()
		end
	elseif key == "cross" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_CROSS)
		elseif shell == "win" then	return pad:cross()
		end
	elseif key == "square" then
		if shell == "pge" then		return pge.controls.pressed(PGE_CTRL_SQUARE)
		elseif shell == "win" then	return pad:square()
		end
	end
	return -1
end

function shell_mathfloor(n)
	if shell == "pge" then		return pge.math.floor(n)
	elseif shell == "win" then	return math.floor(n)
	end
end

function shell_mathsqrt(n)
	if shell == "pge" then		return pge.math.sqrt(n)
	elseif shell == "win" then	return math.sqrt(n)
	end
end

function shell_loadfont(font, size)
	if shell == "pge" then		return pge.font.load(font, size, PGE_RAM)
	elseif shell == "win" then	return Font.load(font)
	end
end

function shell_fontsize(font, size)
	if shell == "win" then		font:setPixelSizes(size, size) end
end

function shell_print(font, x, y, color, text)
	if shell == "pge" then		pge.font.print(font, x, y, color, text)
	elseif shell == "win" then	screen:fontPrint(font, x + 2, y + 10, text, color) --pourquoi/combien le décalage?
	end
end

function shell_printcenter(font, y, color, text)
	if shell == "pge" then		pge.font.printcenter(font, y, color, text)
	elseif shell == "win" then
		local length = string.len(text)
		local x = 240 - ((length*4) / 2) 
		screen:fontPrint(font, x, y, text, color)
	end
end


